#!/bin/sh
#
# @package      hubzero-submit-distributor
# @file         Scripts/condor/cleanupjob.sh
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright 2004-2014 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2014 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
if [ $# -ne 3 ] ; then
   echo usage: $0 jobWorkingDirectory jobScratchDirectory jobClass
   exit 64
fi

jobWorkingDirectory=$1
jobScratchDirectory=$2
jobClass=$3

sharedFileSystem=1

exitStatus=0
if [ ${jobClass} = PEGASUS ] ; then
   if [ ${jobScratchDirectory} != ${jobWorkingDirectory} ] ; then
      rm -rf ${jobScratchDirectory}
      exitStatus=$?
   else
      rm -rf ${jobScratchDirectory}/scratch
      if [ $? -eq 0 ] ; then
         rm -rf ${jobScratchDirectory}/work
         exitStatus=$?
      else
         exitStatus=$?
      fi
   fi
else
   if [ ${sharedFileSystem} -ne 1 ] ; then
      rm -rf ${jobWorkingDirectory}
      exitStatus=$?
   fi
fi

exit ${exitStatus}
